@@ -338,14 +338,15 @@ class Aurora():
     # 
     # @return object: NoneType -- The root app
     ##
-    def run(self):    
+    def run(self, host:str=None, port:str=None, debug:bool=None):  
         # Fetch the required attributes
-        host = getattr(self.config, "HOST")
-        port = getattr(self.config, "PORT")
+        host = getattr(self.config, "HOST") if host == None else host
+        port = getattr(self.config, "PORT") if port == None else port
+        debug = self.debug if debug == None else debug
 
         # Try to run the app
         try:
-            return self.app.run(host=host, port=port, debug=self.debug)
+            return self.app.run(host=host, port=port, debug=debug)
 
         except NameError as e:
             # Developer mode
