@@ -4,16 +4,14 @@ from .Aurora import Aurora
 # For the sake of init_app
 try:
     from .Controller import Controller
-    from .Template import Template
+    from .Template import View
     from .Forms import Forms
     from .Model import Model
 
-    View = Template().render
-
 # Pass on error
 except:
     pass
 
 # Descriptions
-__version__ = '0.8.20'
+__version__ = '0.8.22'
 __author__ = '<https://github.com/heminsatya>'
